==> openGion6.7.4.1_dev.zip: uap/webapps/ge/db/FIREBIRD/sql/install/01_TABLE/GEA08S.sql <==
/****************************************************************************/
/* GEA08 ( 項目名称定義(ﾗﾍﾞﾙ) )                                             */
/*                                                                          */
/* Created : 2017/01/05 15:19:11                                            */
/****************************************************************************/

CREATE TABLE GEA08 (
   SYSTEM_ID        VARCHAR (   10 )                    NOT NULL            /*  10 ｼｽﾃﾑID   */
 , LANG             VARCHAR (    2 )                    NOT NULL            /*  20 言語     */
 , CLM              VARCHAR (   30 )                    NOT NULL            /*  30 項目     */
 , NAME_JA          VARCHAR (  200 )                                        /*  40 名称     */
 , SNAME            VARCHAR (   60 )                                        /*  50 名前(短) */
 , LNAME            VARCHAR (  500 )                                        /*  60 名前(長) */
 , DESCRIPTION      VARCHAR ( 4000 )                                        /*  70 概要説明 */
 , KBLBL            VARCHAR (    1 )                    NOT NULL            /*  80 ﾗﾍﾞﾙ区分 */
 , COMMENTS         VARCHAR (  500 )                                        /*  90 ｺﾒﾝﾄ     */
 , CDKH             VARCHAR (    1 )                                        /* 100 改廃ｺｰﾄﾞ */
 , FGLOAD           VARCHAR (    1 )        DEFAULT '0' NOT NULL            /* 110 読込F    */
 , KBSAKU           VARCHAR (    1 )        DEFAULT '1' NOT NULL            /* 120 作成区分 */
 , RELEASE_NOTES    VARCHAR (  120 )                                        /* 130 ﾘﾘｰｽﾉｰﾄ  */
 , RDC_CODE         VARCHAR (   20 )                                        /* 190 設変番号 */
 , UNIQ             BIGINT                              NOT NULL            /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ              VARCHAR (    1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET            VARCHAR (   14 )                                        /* 820 登録日時 */
 , PGSET            VARCHAR (   10 )                                        /* 830 作成PG   */
 , PGPSET           VARCHAR (   10 )                                        /* 840 作成親PG */
 , USRSET           VARCHAR (   10 )                                        /* 850 作成社員 */
 , DYUPD            VARCHAR (   14 )                                        /* 860 更新日時 */
 , PGUPD            VARCHAR (   10 )                                        /* 870 更新PG   */
 , PGPUPD           VARCHAR (   10 )                                        /* 880 更新親PG */
 , USRUPD           VARCHAR (   10 )                                        /* 890 更新者   */
);


CREATE SEQUENCE GEA08S00 ;


CREATE TRIGGER GEA08T00 FOR GEA08
  BEFORE INSERT AS 
  BEGIN 
    NEW.UNIQ = GEN_ID( GEA08S00,1 );
  END;

==> openGion7.0.3.0_dev.zip: uap/webapps/ge/db/FIREBIRD/sql/install/01_TABLE/GEA08S.sql <==
/****************************************************************************/
/* GEA08 ( 項目名称定義(ﾗﾍﾞﾙ) )                                             */
/*                                                                          */
/* Created : 2018/09/28 16:03:35                                            */
/****************************************************************************/

CREATE TABLE GEA08 (
   SYSTEM_ID        VARCHAR (   10 )                    NOT NULL            /*  10 ｼｽﾃﾑID   */
 , LANG             VARCHAR (    2 )                    NOT NULL            /*  20 言語     */
 , CLM              VARCHAR (   50 )                    NOT NULL            /*  30 項目     */
 , NAME_JA          VARCHAR (  200 )                                        /*  40 名称     */
 , SNAME            VARCHAR (   60 )                                        /*  50 名前(短) */
 , LNAME            VARCHAR (  500 )                                        /*  60 名前(長) */
 , DESCRIPTION      VARCHAR ( 4000 )                                        /*  70 概要説明 */
 , KBLBL            VARCHAR (    1 )                    NOT NULL            /*  80 ﾗﾍﾞﾙ区分 */
 , COMMENTS         VARCHAR (  500 )                                        /*  90 ｺﾒﾝﾄ     */
 , CDKH             VARCHAR (    1 )                                        /* 100 改廃ｺｰﾄﾞ */
 , FGLOAD           VARCHAR (    1 )        DEFAULT '0' NOT NULL            /* 110 読込F    */
 , KBSAKU           VARCHAR (    1 )        DEFAULT '1' NOT NULL            /* 120 作成区分 */
 , RELEASE_NOTES    VARCHAR (  120 )                                        /* 130 ﾘﾘｰｽﾉｰﾄ  */
 , RDC_CODE         VARCHAR (   20 )                                        /* 190 設変番号 */
 , UNIQ             BIGINT                              NOT NULL            /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ              VARCHAR (    1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET            VARCHAR (   14 )                                        /* 820 登録日時 */
 , PGSET            VARCHAR (   10 )                                        /* 830 作成PG   */
 , PGPSET           VARCHAR (   10 )                                        /* 840 作成親PG */
 , USRSET           VARCHAR (   10 )                                        /* 850 作成者   */
 , DYUPD            VARCHAR (   14 )                                        /* 860 更新日時 */
 , PGUPD            VARCHAR (   10 )                                        /* 870 更新PG   */
 , PGPUPD           VARCHAR (   10 )                                        /* 880 更新親PG */
 , USRUPD           VARCHAR (   10 )                                        /* 890 更新者   */
);


CREATE SEQUENCE GEA08S00 ;


CREATE TRIGGER GEA08T00 FOR GEA08
  BEFORE INSERT AS 
  BEGIN 
    NEW.UNIQ = GEN_ID( GEA08S00,1 );
  END;
